@@ -1,7 +1,12 @@
+# Add the native FFMPEG and MinGW libraries to executable path, so that the
+# AV pyd files can find them.
+import os
+if os.name == 'nt':
+    os.environ['PATH'] = os.path.abspath(os.path.dirname(__file__)) + os.pathsep + os.environ['PATH']
 
 # MUST import the core before anything else in order to initalize the underlying
 # library that is being wrapped.
-from ._core import time_base
+from ._core import time_base, pyav_version as __version__
 
 # Capture logging (by importing it).
 from . import logging
